=begin
Copyright 2011-2015 (c) TIG
All Rights Reserved.
THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED 
WARRANTIES,INCLUDING,WITHOUT LIMITATION,THE IMPLIED WARRANTIES OF 
MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
###
Usage:
Menu "View" > "ImportCamera..."
Choose the file containing the camera data, in the following format:

name,xeye,yeye,zeye,xtarget,ytarget,ztarget,rollangle,fovangle

From v1.2 there can be an optional value added after 'fovangle':

,image

This can be the full path to the image, e.g. 'C:/.../my_folder/my_image.png'
or if the image is with the camera data file just its name, e.g. 'my_image.png'
The new scene-tab's name will be 'name'+' [PhotoMatch]', and it will then use 
that image as a 'photomatch' background-image.***
TIP: if image or image-path contain spaces, do NOT use ' ' as the TIG::ICVSEP 
because the full image name/path will not be correctly parsed from the data.

You can have one camera per line.

The xyz values should be in 'METERS'.
The two angles should be in degrees.
If the ",rollangle," is replaced with ",upx,upy,upz," a vector can be used.

New scene-tabs are made, each called 'name', with cameras as specified.***

Edit the ICVSEP and ICDSEP constants below to suit your typical file's 
value-separator [' ',;:\t] and decimal.separator [. or ,]...

###
Donations:
info @ revitrev.org via PayPal.com
Version:
1.0 20110908 First issue.
1.1 20110910 METER version.
1.2 20150124 Background-images optional.
1.3 20150126 Camera data used with images.
###
=end

require "sketchup.rb"

module TIG
    ### sort out value and decimal separator here...
    ICVSEP=' ' ### could be ' ', ',', '\t', ';', ':' etc
    ICDSEP=',' ### could be '.' or ','
    ###
def self.importcamera()
	fname=UI.openpanel("ImportCamera...",'','')
	return nil unless fname && File.exist?(fname)
	model=Sketchup.active_model
	pages=model.pages
	view=model.active_view
	lines=IO.readlines(fname)
	lines.each{|data|
		data.chomp!
		next unless data && ! data.empty?
    line=data.split(ICVSEP)
		page_name=line[0]
		image=line[-1]
        line.each{|lin|
          lin.strip!
          lin.tr!(ICDSEP, '.')
        }
		eye=[line[1].to_f.m, line[2].to_f.m, line[3].to_f.m]
		target=[line[4].to_f.m, line[5].to_f.m, line[6].to_f.m]
        vec=eye.vector_to(target)
        if line[10] ### up is given as a vector
		      up=Geom::Vector3d.new(line[7].to_f.m, line[8].to_f.m, line[9].to_f.m)
          up=Y_AXIS if up.parallel?(vec)
          up=Z_AXIS if up.parallel?(vec)
          up=X_AXIS if up.parallel?(vec)
          fov=line[10].to_f  ### degrees
        else ### up is calculated from an angle
          ang=line[7].to_f.degrees ### degrees>radians
          up=Z_AXIS.clone
          tr=Geom::Transformation.rotation(eye, vec, ang)
          up.transform!(tr)
          up=Y_AXIS if up.parallel?(vec)
          up=Z_AXIS if up.parallel?(vec)
          up=X_AXIS if up.parallel?(vec)
          fov=line[8].to_f ### degrees
        end
		cam=Sketchup::Camera.new(eye, target, up, true, fov)
		view.camera=cam
		if image && img=File.exist?(image)
			img=image
		elsif image && File.exist?(File.join(File.dirname(fname), image))
			img=(File.join(File.dirname(fname), image))
		else
			img=nil
		end
		if img
			new_page = pages.add_matchphoto_page(img, cam, page_name+' [PhotoMatch]')
			### cam OR nil takes the camera from the image
		else
			new_page = pages.add(page_name)
		end
	}
end#def

unless file_loaded?(__FILE__)
	UI.menu("View").add_item("ImportCamera..."){self.importcamera()}
end
file_loaded(__FILE__)

end#module
